@@ -1,4 +1,4 @@
-from flask_monitoringdashboard.core.profiler.util import order_histogram
+from lemonadefashion_flask_monitoringdashboard.core.profiler.util import order_histogram
 
 
 def test_order_histogram():
