@@ -1,6 +1,6 @@
 import pytest
 
-from flask_monitoringdashboard.core.measurement import init_measurement, add_decorator
+from lemonadefashion_flask_monitoringdashboard.core.measurement import init_measurement, add_decorator
 
 
 @pytest.mark.usefixtures('request_context')
