@@ -1,10 +1,10 @@
 """
 This file contains all unit tests that count a number of results in the database.
-(Corresponding to the file: 'flask_monitoringdashboard/database/count.py')
+(Corresponding to the file: 'lemonadefashion_flask_monitoringdashboard/database/count.py')
 """
 import pytest
 
-from flask_monitoringdashboard.database.code_line import get_code_line
+from lemonadefashion_flask_monitoringdashboard.database.code_line import get_code_line
 
 
 @pytest.mark.parametrize('filename', ['filename'])
